@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2013-2015  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2013-2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -18,6 +18,7 @@
 
 #include "snore.h"
 #include "snore_p.h"
+#include "lambdahint.h"
 #include "notification/notification.h"
 #include "notification/notification_p.h"
 #include "plugins/plugincontainer.h"
@@ -48,6 +49,11 @@ SnoreCore &SnoreCore::instance()
 {
     static SnoreCore *instance = nullptr;
     if (!instance) {
+        qRegisterMetaType<Application>();
+        qRegisterMetaType<LambdaHint>();
+        qRegisterMetaType<Notification>();
+        qRegisterMetaType<SnorePlugin::PluginTypes>();
+        qRegisterMetaTypeStreamOperators<SnorePlugin::PluginTypes>();
         instance = new SnoreCore(qApp);
         SnoreCorePrivate::instance()->init();
     }
@@ -182,8 +188,11 @@ bool SnoreCore::setPrimaryNotificationBackend(const QString &backend)
 void SnoreCore::requestCloseNotification(Notification n, Notification::CloseReasons r)
 {
     Q_D(SnoreCore);
-
-    if (d->m_notificationBackend) {
+    bool wasQued  = d->m_notificationQue.removeOne(n);
+    if (wasQued) {
+        snoreDebug(SNORE_DEBUG) << n << " was qued.";
+    }
+    if (!wasQued && d->m_notificationBackend) {
         d->m_notificationBackend->requestCloseNotification(n, r);
     } else {
         if (n.isValid()) {
@@ -249,10 +258,10 @@ Notification SnoreCore::getActiveNotificationByID(uint id) const
     return d->m_activeNotifications.value(id);
 }
 
-void SnoreCore::displayExapleNotification()
+void SnoreCore::displayExampleNotification()
 {
     Application app = SnoreCorePrivate::instance()->defaultApplication();
-    QString text = QLatin1String("<i>") + tr("This is ") + app.name() + QLatin1String("</i><br>"
+    QString text = QLatin1String("<i>") + tr("This is %1").arg(app.name()) + QLatin1String("</i><br>"
                    "<b>") + tr("Everything is awesome!") + QLatin1String("</b><br>");
     if (!app.constHints().value("use-markup").toBool()) {
         text = Utils::normalizeMarkup(text, Utils::NO_MARKUP);
