@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2014  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2014-2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -28,7 +28,6 @@
 #include <QApplication>
 #include <QSettings>
 #include <QTemporaryDir>
-#include <QTranslator>
 
 using namespace Snore;
 
@@ -94,7 +93,7 @@ bool SnoreCorePrivate::setBackendIfAvailible(const QString &backend)
         if (!b->isReady()) {
             snoreDebug(SNORE_DEBUG) << "Backend not ready:" << b->errorString();
 
-            emit q->prmaryNotificationBackendError(b->errorString());
+            emit q->primaryNotificationBackendError(b->errorString());
             return false;
         }
         if (m_notificationBackend) {
@@ -107,7 +106,7 @@ bool SnoreCorePrivate::setBackendIfAvailible(const QString &backend)
         connect(b, &SnoreBackend::error, [this, b](const QString &) {
             slotInitPrimaryNotificationBackend();
         });
-        emit q->prmaryNotificationBackendChanged(b->name());
+        emit q->primaryNotificationBackendChanged(b->name());
         return true;
     }
     return false;
@@ -206,8 +205,12 @@ void SnoreCorePrivate::setLocalSttingsPrefix(const QString &prefix)
 
 QString SnoreCorePrivate::tempPath()
 {
+#if 1
     static QTemporaryDir dir;
     return dir.path();
+#else
+    return QDir::temp().path() + QLatin1String("/libsnore/");
+#endif
 }
 
 // TODO: this is somehow horrible code
@@ -267,49 +270,3 @@ void SnoreCorePrivate::startNotificationTimeoutTimer(Notification notification)
     timer->start();
 }
 
-///Startup code
-
-static void loadTranslator()
-{
-    auto installTranslator = [](const QString & locale) {
-        snoreDebug(SNORE_DEBUG) << locale;
-        if (locale != QLatin1String("C")) {
-            QTranslator *translator = new QTranslator(qApp->instance());
-            if (translator->load(locale, QLatin1String(":/lang/libsnore/"))) {
-                snoreDebug(SNORE_DEBUG) << "Using system locale:" << locale;
-                snoreDebug(SNORE_DEBUG) << qApp->installTranslator(translator);
-            } else {
-                translator->deleteLater();
-                QString fileName = QLatin1String(":/lang/libsnore/") + locale + QLatin1String(".qm");
-                snoreDebug(SNORE_DEBUG) << "Failed to load translations for:" << locale << fileName << QFile::exists(fileName) ;
-                return false;
-            }
-        }
-        return true;
-    };
-
-    installTranslator(QLatin1String("en"));
-    QLocale locale = QLocale::system();
-    if (locale.name() != QLatin1String("en")) {
-        if (!installTranslator(locale.name())) {
-            installTranslator(locale.bcp47Name());
-        }
-    }
-}
-
-static void registerMetaTypes()
-{
-    qRegisterMetaType<Notification>();
-    qRegisterMetaType<Application>();
-    qRegisterMetaType<SnorePlugin::PluginTypes>();
-    qRegisterMetaTypeStreamOperators<SnorePlugin::PluginTypes>();
-}
-
-static void snoreStartup()
-{
-    loadTranslator();
-    registerMetaTypes();
-}
-
-Q_COREAPP_STARTUP_FUNCTION(snoreStartup)
-
