@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2013-2014  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2013-2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -44,7 +44,7 @@ private:
 
 };
 
-Q_DECLARE_METATYPE(FreedesktopImageHint);
+Q_DECLARE_METATYPE(FreedesktopImageHint)
 
 QDBusArgument &operator<<(QDBusArgument &a,  const FreedesktopImageHint &i);
 const QDBusArgument &operator >>(const QDBusArgument &a,  FreedesktopImageHint  &i) ;
