@@ -16,9 +16,11 @@ FreedesktopBackend::FreedesktopBackend()
             QLatin1String("/org/freedesktop/Notifications"),
             QDBusConnection::sessionBus(), this);
     QDBusPendingReply<QStringList> reply = m_interface->GetCapabilities();
-    reply.waitForFinished();
-    QStringList caps  = reply.value();
-    m_supportsRichtext = caps.contains(QLatin1String("body-markup"));
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, [reply, watcher, this]() {
+        m_supportsRichtext = reply.value().contains(QLatin1String("body-markup"));
+        watcher->deleteLater();
+    });
     connect(this, &FreedesktopBackend::enabledChanged, [this](bool enabled) {
         if (enabled) {
             connect(m_interface, &org::freedesktop::Notifications::ActionInvoked, this, &FreedesktopBackend::slotActionInvoked);
@@ -48,20 +50,19 @@ void  FreedesktopBackend::slotNotify(Notification noti)
     }
 
     QStringList actions;
-    foreach (int k, noti.actions().keys()) {
+    foreach(int k, noti.actions().keys()) {
         actions << QString::number(k) << noti.actions()[k].name();
     }
     QVariantMap hints;
-    if (noti.icon().isValid()) {
-        FreedesktopImageHint image(noti.icon().image());
-        hints.insert(QLatin1String("image_data"), QVariant::fromValue(image));
-    }
 
-    char urgency = '1';
+    FreedesktopImageHint image(noti.icon().pixmap(QSize(128, 128)).toImage());
+    hints.insert(QLatin1String("image_data"), QVariant::fromValue(image));
+
+    char urgency = 1;
     if (noti.priority() < 0) {
-        urgency = '0';
+        urgency = 0;
     } else if (noti.priority() > 2) {
-        urgency = '2';
+        urgency = 2;
     }
     hints.insert(QLatin1String("urgency"), urgency);
 
@@ -69,6 +70,8 @@ void  FreedesktopBackend::slotNotify(Notification noti)
         hints.insert(QLatin1String("desktop-entry"), noti.application().constHints().value("desktop-entry"));
     }
 
+    hints.insert(QLatin1String("suppress-sound"), noti.constHints().value("silent").toBool());
+
     uint updateId = 0;
     if (noti.isUpdate()) {
         updateId = noti.old().hints().privateValue(this, "id").toUInt();
