@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2015  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -29,9 +29,9 @@ PushoverSettings::PushoverSettings(Snore::SnorePlugin *plugin, QWidget *parent)
     m_deviceLineEdit(new QLineEdit(this))
 {
     addRow(tr("User Key:"), m_keyLineEdit, tr("The user key which can be found on your account page at <a href=\"https://pushover.net\">Pushover.net</a>."));
-    addRow(tr("Sound:"), m_soundLineEdit, tr("The pushover sound that it played when a notification is recieved."));
-    addRow(tr("Devices:"), m_deviceLineEdit, tr("The devices that are to recieve the notifications."));
-    addRow(QString(), new QLabel(tr("If you don't have an accout yet please register at <a href=\"https://pushover.net\">Pushover.net</a>"),this));
+    addRow(tr("Sound:"), m_soundLineEdit, tr("The pushover sound that is played when a notification is received."));
+    addRow(tr("Devices:"), m_deviceLineEdit, tr("The devices that are to receive the notifications."));
+    addRow(QString(), new QLabel(tr("If you don't have an account yet please register at <a href=\"https://pushover.net\">Pushover.net</a>"), this));
 }
 
 PushoverSettings::~PushoverSettings()
