@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2015  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +26,7 @@ ToastySettings::ToastySettings(Snore::SnorePlugin *plugin, QWidget *parent) :
     Snore::PluginSettingsWidget(plugin, parent),
     m_lineEdit(new QLineEdit)
 {
-    addRow(tr("Device ID:"), m_lineEdit, tr("The device id which can be foun in the toasty app."));
+    addRow(tr("Device ID:"), m_lineEdit, tr("The device id which can be found in the toasty app."));
     addRow(QString(), new QLabel(tr("<a href=\"http://supertoasty.com/\">Supertoasty.com</a>"), this));
 }
 
